@@ -26,7 +26,7 @@ class Wimby:
         self.momentum = _historical_averages(self.coins, self.debug)
         self.movers = _movements(self.momentum, self.debug)
     
-    def dump(self):
+    def dump(self, yesterday={}):
         if self.movers.count() > 0:
             print("Wimby Cryptocurrency Analysis")
             print("\n[NOTES]")
@@ -51,6 +51,11 @@ class Wimby:
             print("    * More than 80% Buy Trend is suggestive to HOLD or STRONGLY  BUY at your discretion.")
             print("6. Use the three (3) metrics to hold or trade strategically.")
             print("\n[WAVG Analytics]")
+            comparison = {}
+            if isinstance(yesterday, dict):
+                for rank, tokens in yesterday.items():
+                    for token in tokens:
+                        comparison.update({token: rank})
             ranking = list(sorted([float(x) for x in self.movers.keys()]))
             minn = len(str(int((min(ranking) * 100)))) + 3
             maxn = len(str(int((max(ranking) * 100)))) + 3
@@ -61,10 +66,18 @@ class Wimby:
                 movement = rank * 100
                 market_trend.append(movement)
                 for token in tokens:
+                    previous = float(comparison.get(token, 0))
+                    change = 0
+                    if previous > 0:
+                        change = ((previous - rank) / rank) * 100
                     fmovement = f"{movement:,.2f}"
                     while len(fmovement) < padding:
                         fmovement = f" {fmovement}"
-                    print(f"{fmovement} {token}")
+                    
+                    if change == 0:
+                        print(f"{fmovement} {token}")
+                    else:
+                        print(f"{fmovement} {token} ({change:,.2f}%)")
                     pattern = self.momentum.get(token, {}).get("trend", "")
                     if pattern.strip() != "":
                         print(f"    {pattern}")
